@@ -3,68 +3,52 @@
 
   This file is part of libkdepim.
 
-  Copyright (C) 2004 Till Adam <adam@kde.org>
+  SPDX-FileCopyrightText: 2004 Till Adam <adam@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KDEPIM_PROGRESSMANAGER_H
-#define KDEPIM_PROGRESSMANAGER_H
+#pragma once
 
 #include "kdepim_export.h"
 
-#include <QObject>
-#include <QString>
-#include <QMap>
 #include <QHash>
+#include <QMap>
+#include <QObject>
 #include <QPointer>
+#include <QString>
 
-namespace KPIM {
+namespace KPIM
+{
 class ProgressItem;
 class ProgressManager;
-typedef QMap<ProgressItem *, bool> ProgressItemMap;
-
+using ProgressItemMap = QMap<ProgressItem *, bool>;
+/**
+ * @brief The ProgressItem class
+ */
 class KDEPIM_EXPORT ProgressItem : public QObject
 {
     Q_OBJECT
     friend class ProgressManager;
 
 public:
-
-    enum CryptoStatus {
-        Encrypted,
-        Unencrypted,
-        Unknown
-    };
+    enum CryptoStatus { Encrypted, Unencrypted, Unknown };
 
     /**
      * @return The id string which uniquely identifies the operation
      *         represented by this item.
      */
-    const QString &id() const;
+    Q_REQUIRED_RESULT const QString &id() const;
 
     /**
      * @return The parent item of this one, if there is one.
      */
-    ProgressItem *parent() const;
+    Q_REQUIRED_RESULT ProgressItem *parent() const;
 
     /**
      * @return The user visible string to be used to represent this item.
      */
-    const QString &label() const;
+    Q_REQUIRED_RESULT const QString &label() const;
 
     /**
      * @param v Set the user visible string identifying this item.
@@ -74,7 +58,7 @@ public:
     /**
      * @return The string to be used for showing this item's current status.
      */
-    const QString &status() const;
+    Q_REQUIRED_RESULT const QString &status() const;
     /**
      * Set the string to be used for showing this item's current status.
      * @param v The status string.
@@ -84,7 +68,7 @@ public:
     /**
      * @return Whether this item can be canceled.
      */
-    bool canBeCanceled() const;
+    Q_REQUIRED_RESULT bool canBeCanceled() const;
 
     /**
      * @param b Set if can be canceled
@@ -95,7 +79,7 @@ public:
      * @return Whether this item uses secure communication
      * (Account uses ssl, for example.).
      */
-    CryptoStatus cryptoStatus() const;
+    Q_REQUIRED_RESULT CryptoStatus cryptoStatus() const;
 
     /**
      * Set whether this item uses crypted communication, so listeners
@@ -107,7 +91,7 @@ public:
     /**
      * @return whether this item uses a busy indicator instead of real progress display
      */
-    bool usesBusyIndicator() const;
+    Q_REQUIRED_RESULT bool usesBusyIndicator() const;
 
     /**
      * Sets whether this item uses a busy indicator instead of real progress for its progress bar.
@@ -119,7 +103,7 @@ public:
     /**
      * @return The current progress value of this item in percent.
      */
-    unsigned int progress() const;
+    Q_REQUIRED_RESULT unsigned int progress() const;
 
     /**
      * Set the progress (percentage of completion) value of this item.
@@ -146,10 +130,10 @@ public:
 
     // Often needed values for calculating progress.
     void setTotalItems(unsigned int v);
-    unsigned int totalItems() const;
+    Q_REQUIRED_RESULT unsigned int totalItems() const;
     void setCompletedItems(unsigned int v);
     void incCompletedItems(unsigned int v = 1);
-    unsigned int completedItems() const;
+    Q_REQUIRED_RESULT unsigned int completedItems() const;
 
     /**
      * Recalculate progress according to total/completed items and update.
@@ -299,17 +283,17 @@ public:
     static QString getUniqueID();
 
     /**
-      * Creates a ProgressItem with a unique id and the given label.
-      * This is the simplest way to acquire a progress item. It will not
-      * have a parent and will be set to be cancellable and not using crypto.
-      */
+     * Creates a ProgressItem with a unique id and the given label.
+     * This is the simplest way to acquire a progress item. It will not
+     * have a parent and will be set to be cancellable and not using crypto.
+     */
     static ProgressItem *createProgressItem(unsigned int progressType, const QString &label);
 
     /**
-      * Creates a ProgressItem with a unique id and the given label.
-      * This is the simplest way to acquire a progress item. It will not
-      * have a parent and will be set to be cancellable and not using crypto.
-      */
+     * Creates a ProgressItem with a unique id and the given label.
+     * This is the simplest way to acquire a progress item. It will not
+     * have a parent and will be set to be cancellable and not using crypto.
+     */
     static ProgressItem *createProgressItem(const QString &label);
 
     /**
@@ -326,21 +310,32 @@ public:
      * canceled) and ongoing children prevent parents from finishing.
      * @return The ProgressItem representing the operation.
      */
-    static ProgressItem *createProgressItem(ProgressItem *parent, const QString &id, const QString &label,
-                                            const QString &status = QString(), bool canBeCanceled = true, KPIM::ProgressItem::CryptoStatus cryptoStatus = KPIM::ProgressItem::Unencrypted);
+    static ProgressItem *createProgressItem(ProgressItem *parent,
+                                            const QString &id,
+                                            const QString &label,
+                                            const QString &status = QString(),
+                                            bool canBeCanceled = true,
+                                            KPIM::ProgressItem::CryptoStatus cryptoStatus = KPIM::ProgressItem::Unencrypted);
 
     /**
      * Use this version if you have the id string of the parent and want to
      * add a subjob to it.
      */
-    static ProgressItem *createProgressItem(const QString &parent, const QString &id, const QString &label,
-                                            const QString &status = QString(), bool canBeCanceled = true, KPIM::ProgressItem::CryptoStatus cryptoStatus = KPIM::ProgressItem::Unencrypted);
+    static ProgressItem *createProgressItem(const QString &parent,
+                                            const QString &id,
+                                            const QString &label,
+                                            const QString &status = QString(),
+                                            bool canBeCanceled = true,
+                                            KPIM::ProgressItem::CryptoStatus cryptoStatus = KPIM::ProgressItem::Unencrypted);
 
     /**
      * Version without a parent.
      */
-    static ProgressItem *createProgressItem(const QString &id, const QString &label,
-                                            const QString &status = QString(), bool canBeCanceled = true, KPIM::ProgressItem::CryptoStatus cryptoStatus = KPIM::ProgressItem::Unencrypted);
+    static ProgressItem *createProgressItem(const QString &id,
+                                            const QString &label,
+                                            const QString &status = QString(),
+                                            bool canBeCanceled = true,
+                                            KPIM::ProgressItem::CryptoStatus cryptoStatus = KPIM::ProgressItem::Unencrypted);
 
     /**
      * @return true when there are no more progress items.
@@ -410,16 +405,25 @@ private:
     // prevent unsolicited copies
     ProgressManager(const ProgressManager &);
 
-    ProgressItem *createProgressItemImpl(ProgressItem *parent, const QString &id, const QString &label, const QString &status, bool cancellable, ProgressItem::CryptoStatus cryptoStatus,
+    ProgressItem *createProgressItemImpl(ProgressItem *parent,
+                                         const QString &id,
+                                         const QString &label,
+                                         const QString &status,
+                                         bool cancellable,
+                                         ProgressItem::CryptoStatus cryptoStatus,
                                          unsigned int progressType = 0);
 
-    ProgressItem *createProgressItemImpl(const QString &parent, const QString &id, const QString &label, const QString &status, bool cancellable, ProgressItem::CryptoStatus cryptoStatus,
+    ProgressItem *createProgressItemImpl(const QString &parent,
+                                         const QString &id,
+                                         const QString &label,
+                                         const QString &status,
+                                         bool cancellable,
+                                         ProgressItem::CryptoStatus cryptoStatus,
                                          unsigned int progressType = 0);
     void emitShowProgressDialogImpl();
 
-    QHash< QString, ProgressItem * > mTransactions;
+    QHash<QString, ProgressItem *> mTransactions;
     static unsigned int uID;
 };
 }
 
-#endif // __KPIM_PROGRESSMANAGER_H__
